@@ -406,7 +406,7 @@ def la_find_partition(**kwargs):
 
 ###
 
-def find_communities(X, pp_method = 'None', method = 'tani', nbr_num = 10, n_threads = None, verbose = False, keep_temp_files = False, temp_name = '', partition_type = la.RBConfigurationVertexPartition, resolution = 0.8, seed = None, local = False): 
+def find_communities(X, pp_method = None, method = 'tani', nbr_num = 10, n_threads = None, verbose = False, keep_temp_files = False, temp_name = '', partition_type = la.RBConfigurationVertexPartition, resolution = 0.8, seed = None, local = False): 
     """_summary_
 
     Parameters
@@ -454,6 +454,8 @@ def find_communities(X, pp_method = 'None', method = 'tani', nbr_num = 10, n_thr
             uid = uuid.uuid1().hex
         else: uid = temp_name
         knng_temp = uid + '.ijv'
+        if n_threads is None:
+            n_threads = os.cpu_count()
 
         save_as_ijv(knng_temp, normalize(X, norm='l2', axis=1, copy=True))
         if verbose:
@@ -498,8 +500,7 @@ def find_communities(X, pp_method = 'None', method = 'tani', nbr_num = 10, n_thr
         print("#### Finish pruning process and build igraph graph in {0:.2f} seconds".format(time.time() - tic_prune))
 
     ## find communities using Leiden algorithm with default settings
-    if n_threads is None:
-        n_threads = os.cpu_count()
+
 
     tic_la = time.time()
     if hasattr(partition_type, 'resolution_parameter'):
